import { Include, UnitResponse, UnitConfig, BaseListParams } from "../types/common";
import { Customer } from "../types/customer";
import { CreateAccountRequest, Account, PatchAccountRequest, AccountLimits, AccountDepositProduct, CloseAccountRequest, FreezeAccountRequest, AccountOwnersRequest } from "../types/account";
import { BaseResource } from "./baseResource";
export declare class Accounts extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateAccountRequest): Promise<UnitResponse<Account>>;
    closeAccount(request: CloseAccountRequest): Promise<UnitResponse<Account>>;
    reopenAccount(accountId: string): Promise<UnitResponse<Account>>;
    freezeAccount(request: FreezeAccountRequest): Promise<UnitResponse<Account>>;
    unfreezeAccount(accountId: string): Promise<UnitResponse<Account>>;
    /**
     * Include is Optional. Related resource available to include: customer. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources)
     * @param accountId
     * @param include
     */
    get(accountId: string, include?: string): Promise<UnitResponse<Account> & Include<Customer[]>>;
    list(params?: AccountListParams): Promise<UnitResponse<Account[]> & Include<Customer[]>>;
    update(request: PatchAccountRequest): Promise<UnitResponse<Account>>;
    limits(accountId: string): Promise<UnitResponse<AccountLimits>>;
    getAvailableDepositProducts(accountId: string): Promise<UnitResponse<AccountDepositProduct[]>>;
    addOwners(request: AccountOwnersRequest): Promise<UnitResponse<Account>>;
    removeOwners(request: AccountOwnersRequest): Promise<UnitResponse<Account>>;
    enterDaca(accountId: string): Promise<UnitResponse<Account>>;
    activateDaca(accountId: string): Promise<UnitResponse<Account>>;
    deactivateDaca(accountId: string): Promise<UnitResponse<Account>>;
}
export interface AccountListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter Applications by [Tags](https://developers.unit.co/#tags).
     * default: empty
     */
    tags?: object;
    /**
     * Optional. Filter Account by its status (Open, Frozen, or Closed). Usage example: filter[status][0]=Closed
     */
    status?: string[];
    /**
     * Optional. Related resource available to include: customer. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources).
     * default: empty
     */
    include?: string;
    /**
     * Optional. Filters Accounts that have balance higher or equal to the specified amount (in cents). e.g. 5000
     */
    fromBalance?: number;
    /**
     * Optional. Filters Accounts that have balance lower or equal to the specified amount (in cents). e.g. 7000
     */
    toBalance?: number;
    /**
     * Optional. Filters Accounts by type. Valid values are deposit or credit.
     */
    type?: string;
}
