"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckDeposits = void 0;
const baseResource_1 = require("./baseResource");
class CheckDeposits extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/check-deposits", config);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": params.tags }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt",
            "include": (params === null || params === void 0 ? void 0 : params.include) ? params.include : "include"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async get(id, include = "") {
        return this.httpGet(`/${id}`, { params: { include } });
    }
    async update(request) {
        return this.httpPatch(`/${request.checkDepositId}`, { data: request.data });
    }
    async upload(request) {
        let path = `/${request.checkDepositId}`;
        path += request.isBackSide ? "/back" : "/front";
        const headers = { "Content-Type": "image/jpeg" };
        return this.httpPut(path, request.file, { headers });
    }
    async getImage(id, front = true, responseEncoding = "binary", responseType = "blob") {
        const p = front ? "front" : "back";
        return this.httpGet(`/${id}/${p}`, { responseEncoding, responseType });
    }
    async confirm(id) {
        return this.httpPost(`/${id}/confirm`);
    }
}
exports.CheckDeposits = CheckDeposits;
